@@ -124,6 +124,12 @@ def attach_stitch_lua_scripts(redis_client):
                 expire_postfix=PROFILE_VALUE_EXPIRE_AT_POSTFIX
             ))
 
+    if not hasattr(redis_client, 'delete_stitched_user_profile'):
+
+        redis_client.delete_stitched_user_profile = redis_client.register_script(
+            LuaScripts.delete_stitched_user_profile()
+        )
+
     if not hasattr(redis_client, 'remove_stitch_keys_from_pool'):
 
         redis_client.remove_stitch_keys_from_pool = redis_client.register_script(
