@@ -407,6 +407,29 @@ class LuaScripts(object):
                    created_postfix=created_postfix,
                    expire_postfix=expire_postfix)
 
+    @classmethod
+    def delete_stitched_user_profile(cls):
+
+        '''
+        KEYS[1]: all profile keys key
+        ARGV[1]: json array of profile_pool_keys
+        '''
+
+        return '''
+            local profile_pool_keys = cjson.decode(ARGV[1])
+    
+            for idx, profile_pool_key in pairs(profile_pool_keys) do
+                local profile_keys = redis.call('SMEMBERS', profile_pool_key)
+    
+                for ix, profile_key in pairs(profile_keys) do
+                    -- delete the profile
+                    redis.call('DEL', profile_key)
+                    redis.call('ZREM', KEYS[1], profile_key)
+                end
+                redis.call('DEL', profile_pool_key)
+            end         
+        '''
+
     @classmethod
     def get_stitched_user_profile(cls,
                                   updated_postfix,
