@@ -386,6 +386,39 @@ class Profile(object):
 
         self.redis_client.srem(self.users_to_be_cleaned_key, self.user_id)
 
+    @classmethod
+    def delete_stitched(cls,
+                        user_ids):
+
+        # delete the profiles from the cache. Also delete the profile pools. Delete the
+        # profile keys from the set with all profile keys
+        profile_pool_keys = [cls._profile_pool_key(user_id) for user_id in user_ids]
+        cls.redis_client.delete_stitched_user_profile(keys=[cls._all_profile_keys_key()],
+                                                      args=[json.dumps(profile_pool_keys)])
+
+        # delete the profiles from the database
+        cls.delete_from_db_by_user_ids(user_ids=user_ids)
+
+        # delete the pointers from the cache
+        all_pointers_keys = [cls._all_pointers_key(user_id=user_id) for user_id in user_ids]
+        for all_pointers_key, user_id in zip(all_pointers_keys, user_ids):
+            pointers = cls.redis_client.get_all_user_pointers(keys=[all_pointers_key],
+                                                              args=[user_id, json.dumps([])])
+            if pointers:
+                cls.redis_client.delete(*pointers)
+
+        cls.redis_client.delete(*all_pointers_keys)
+
+        # delete the pointers from the database
+        cls.delete_pointers_from_db(user_ids=user_ids)
+
+    @classmethod
+    def delete_pointers_from_db(cls, user_ids):
+
+        pointer_models = cls.django_pointer_model.objects.filter(user_id__in=user_ids)
+        for pointer_model in pointer_models:
+            pointer_model.delete()
+
     @classmethod
     def get_stitched(cls,
                      user_ids,
@@ -489,6 +522,15 @@ class Profile(object):
             return False
         return bool(int(created.decode()))
 
+    @classmethod
+    def delete_from_db_by_user_ids(cls,
+                                   user_ids):
+
+        profile_models = cls.usable_django_model().objects.filter(user_id__in=user_ids)
+        for profile_model in profile_models:
+            profile_model.delete()
+
+
     @classmethod
     def from_database_by_user_ids(cls,
                                   user_ids):
